==> haskell-hsyaml-0.2.1.3-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML
version:              0.2.1.3
visibility:           public
id:                   HsYAML-0.2.1.3-7Ptv7lWKLyWGPx96OoIlyb
key:                  HsYAML-0.2.1.3-7Ptv7lWKLyWGPx96OoIlyb
license:              GPL-2.0-only
copyright:
    2015-2018 Herbert Valerio Riedel
    , 2007-2008 Oren Ben-Kiki

maintainer:           https://github.com/haskell-hvr/HsYAML
author:               Herbert Valerio Riedel
homepage:             https://github.com/haskell-hvr/HsYAML
synopsis:             Pure Haskell YAML 1.2 processor
description:
    @HsYAML@ is a [YAML 1.2](http://yaml.org/spec/1.2/spec.html) processor, i.e. a library for parsing and serializing YAML documents.

    Features of @HsYAML@ include:

    * Pure Haskell implementation with small dependency footprint and emphasis on strict compliance with the [YAML 1.2 specification](http://yaml.org/spec/1.2/spec.html).
    * Direct decoding to native Haskell types via (@aeson@-inspired) typeclass-based API (see "Data.YAML").
    * Allows round-tripping while preserving ordering, anchors, and comments at Event-level.
    * Support for constructing custom YAML node graph representation (including support for cyclic YAML data structures).
    * Support for the standard (untyped) /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" providing implicit typing rules as defined in the YAML 1.2 specification (including support for user-defined custom schemas; see "Data.YAML.Schema").
    * Support for emitting YAML using /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" (including support for user-defined custom encoding schemas; see "Data.YAML.Schema").
    * Event-based API resembling LibYAML'\''s Event-based API (see "Data.YAML.Event").
    * Low-level API access to lexical token-based scanner (see "Data.YAML.Token").

    See also the <//hackage.haskell.org/package/HsYAML-aeson HsYAML-aeson> package which allows to decode and encode YAML by leveraging @aeson@'\''s '\''FromJSON'\'' and '\''ToJSON'\'' instances.

category:             Text
abi:                  797bcd33d388ce77a4564af1276ba8f1
exposed:              True
exposed-modules:
    Data.YAML Data.YAML.Event Data.YAML.Schema Data.YAML.Token

hidden-modules:
    Data.YAML.Loader Data.YAML.Dumper Data.YAML.Internal
    Data.YAML.Event.Internal Data.YAML.Event.Writer Data.YAML.Pos
    Data.YAML.Schema.Internal Data.YAML.Token.Encoding Util Data.DList

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HsYAML-0.2.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HsYAML-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml
hs-libraries:         HSHsYAML-0.2.1.3-7Ptv7lWKLyWGPx96OoIlyb
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 mtl-2.2.2 parsec-3.1.15.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hsyaml/html/HsYAML.haddock
haddock-html:         /usr/share/doc/haskell-hsyaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-0.2.1.3-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML
version:              0.2.1.3
visibility:           public
id:                   HsYAML-0.2.1.3-CKDh8C7ORvL33YMNhb0U1W
key:                  HsYAML-0.2.1.3-CKDh8C7ORvL33YMNhb0U1W
license:              GPL-2.0-only
copyright:
    2015-2018 Herbert Valerio Riedel
    , 2007-2008 Oren Ben-Kiki

maintainer:           https://github.com/haskell-hvr/HsYAML
author:               Herbert Valerio Riedel
homepage:             https://github.com/haskell-hvr/HsYAML
synopsis:             Pure Haskell YAML 1.2 processor
description:
    @HsYAML@ is a [YAML 1.2](http://yaml.org/spec/1.2/spec.html) processor, i.e. a library for parsing and serializing YAML documents.

    Features of @HsYAML@ include:

    * Pure Haskell implementation with small dependency footprint and emphasis on strict compliance with the [YAML 1.2 specification](http://yaml.org/spec/1.2/spec.html).
    * Direct decoding to native Haskell types via (@aeson@-inspired) typeclass-based API (see "Data.YAML").
    * Allows round-tripping while preserving ordering, anchors, and comments at Event-level.
    * Support for constructing custom YAML node graph representation (including support for cyclic YAML data structures).
    * Support for the standard (untyped) /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" providing implicit typing rules as defined in the YAML 1.2 specification (including support for user-defined custom schemas; see "Data.YAML.Schema").
    * Support for emitting YAML using /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" (including support for user-defined custom encoding schemas; see "Data.YAML.Schema").
    * Event-based API resembling LibYAML'\''s Event-based API (see "Data.YAML.Event").
    * Low-level API access to lexical token-based scanner (see "Data.YAML.Token").

    See also the <//hackage.haskell.org/package/HsYAML-aeson HsYAML-aeson> package which allows to decode and encode YAML by leveraging @aeson@'\''s '\''FromJSON'\'' and '\''ToJSON'\'' instances.

category:             Text
abi:                  b8a54d5bd2c86c84a3bd3c4042eec0b6
exposed:              True
exposed-modules:
    Data.YAML Data.YAML.Event Data.YAML.Schema Data.YAML.Token

hidden-modules:
    Data.YAML.Loader Data.YAML.Dumper Data.YAML.Internal
    Data.YAML.Event.Internal Data.YAML.Event.Writer Data.YAML.Pos
    Data.YAML.Schema.Internal Data.YAML.Token.Encoding Util Data.DList

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HsYAML-0.2.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HsYAML-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml
hs-libraries:         HSHsYAML-0.2.1.3-CKDh8C7ORvL33YMNhb0U1W
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 mtl-2.2.2 parsec-3.1.15.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hsyaml/html/HsYAML.haddock
haddock-html:         /usr/share/doc/haskell-hsyaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
